@@ -4,33 +4,38 @@ build_time_vars = {'ABIFLAGS': '',
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ALIGNOF_LONG': 4,
+ 'ALIGNOF_MAX_ALIGN_T': 8,
  'ALIGNOF_SIZE_T': 4,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
- 'AR': 'hppa1.1-unknown-linux-gnu-ar',
+ 'AR': 'hppa2.0-unknown-linux-gnu-ar',
  'ARFLAGS': 'rcs',
- 'BASECFLAGS': '-Wsign-compare',
+ 'BASECFLAGS': '-fno-strict-overflow -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
- 'BINLIBDEST': '/usr/lib/python3.11',
- 'BLDLIBRARY': '-L. -lpython3.11',
- 'BLDSHARED': 'hppa1.1-unknown-linux-gnu-gcc -shared',
+ 'BINLIBDEST': '/usr/lib/python3.12',
+ 'BLDLIBRARY': '-L. -lpython3.12',
+ 'BLDSHARED': 'hppa2.0-unknown-linux-gnu-gcc -shared',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'hppa1.1-unknown-linux-gnu',
+ 'BUILD_GNU_TYPE': 'hppa2.0-unknown-linux-gnu',
+ 'BUILD_SCRIPTS_DIR': 'build/scripts-3.12',
  'BYTESTR_DEPS': '\\',
- 'CC': 'hppa1.1-unknown-linux-gnu-gcc',
+ 'CC': 'hppa2.0-unknown-linux-gnu-gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wsign-compare -DNDEBUG',
+ 'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
+ 'CODECS_COMMON_HEADERS': './Modules/cjkcodecs/multibytecodec.h '
+                          './Modules/cjkcodecs/cjkcodecs.h',
+ 'COMPILEALL_OPTS': '-j1',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
- 'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=1.1 -fwrapv -std=c11 -Wextra '
+ 'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=2.0 -fwrapv -std=c11 -Wextra '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
@@ -40,50 +45,48 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_LDFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed',
  'CONFIGURE_LDFLAGS_NOLTO': '',
- 'CONFIG_ARGS': "'--prefix=/usr' '--build=hppa1.1-unknown-linux-gnu' "
-                "'--host=hppa1.1-unknown-linux-gnu' '--mandir=/usr/share/man' "
+ 'CONFIG_ARGS': "'--prefix=/usr' '--build=hppa2.0-unknown-linux-gnu' "
+                "'--host=hppa2.0-unknown-linux-gnu' '--mandir=/usr/share/man' "
                 "'--infodir=/usr/share/info' '--datadir=/usr/share' "
                 "'--sysconfdir=/etc' '--localstatedir=/var/lib' "
                 "'--datarootdir=/usr/share' "
-                "'--docdir=/usr/share/doc/python-3.11.9' "
-                "'--htmldir=/usr/share/doc/python-3.11.9/html' "
+                "'--docdir=/usr/share/doc/python-3.12.1_p1' "
+                "'--htmldir=/usr/share/doc/python-3.12.1_p1/html' "
                 "'--libdir=/usr/lib' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
                 "'--mandir=/usr/share/man' '--with-computed-gotos' "
                 "'--with-dbmliborder=gdbm' '--with-libc=' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
-                "'--without-lto' '--with-system-expat' '--with-system-ffi' "
-                "'--with-platlibdir=lib' '--with-pkg-config=yes' "
+                "'--without-lto' '--with-system-expat' '--with-platlibdir=lib' "
+                "'--with-pkg-config=yes' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
                 "'--without-assertions' '--disable-optimizations' "
                 "'--with-readline=readline' '--without-valgrind' "
-                "'build_alias=hppa1.1-unknown-linux-gnu' "
-                "'host_alias=hppa1.1-unknown-linux-gnu' "
-                "'PKG_CONFIG=hppa1.1-unknown-linux-gnu-pkg-config' 'CFLAGS=' "
+                "'build_alias=hppa2.0-unknown-linux-gnu' "
+                "'host_alias=hppa2.0-unknown-linux-gnu' "
+                "'PKG_CONFIG=hppa2.0-unknown-linux-gnu-pkg-config' 'CFLAGS=' "
                 "'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw'",
  'CONFINCLUDEDIR': '/usr/include',
- 'CONFINCLUDEPY': '/usr/include/python3.11',
+ 'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.11.9/work/Python-3.11.9/coverage.info',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.12.1_p1/work/Python-3.12.1/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.11.9/work/Python-3.11.9/lcov-report',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.12.1_p1/work/Python-3.12.1/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
-                            '--title "CPython 3.11 LCOV report [commit $(shell '
+                            '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
- 'CXX': 'hppa1.1-unknown-linux-gnu-g++',
- 'DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1',
- 'DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
+ 'CXX': 'hppa2.0-unknown-linux-gnu-g++',
  'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
- 'DEEPFREEZE_DEPS': './Tools/scripts/deepfreeze.py _bootstrap_python '
+ 'DEEPFREEZE_DEPS': './Tools/build/deepfreeze.py _bootstrap_python '
                     './Programs/_freeze_module.py \\',
  'DEEPFREEZE_OBJS': 'Python/deepfreeze/deepfreeze.o',
- 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.11 '
-             '/usr/lib/python3.11/lib-dynload',
- 'DESTLIB': '/usr/lib/python3.11',
+ 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.12 '
+             '/usr/lib/python3.12/lib-dynload',
+ 'DESTLIB': '/usr/lib/python3.12',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/lib/python3.11/lib-dynload',
+ 'DESTSHARED': '/usr/lib/python3.12/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -96,6 +99,8 @@ build_time_vars = {'ABIFLAGS': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_BIG_ENDIAN_IEEE754': 1,
  'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 0,
+ 'DSYMUTIL': '',
+ 'DSYMUTIL_PATH': '',
  'DTRACE': '',
  'DTRACE_DEPS': '\\',
  'DTRACE_HEADERS': '',
@@ -105,13 +110,12 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
- 'EXPAT_CFLAGS': '',
- 'EXPAT_LDFLAGS': '-lexpat',
+ 'EXENAME': '/usr/bin/python3.12',
  'EXPORTSFROM': '',
  'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
- 'EXT_SUFFIX': '.cpython-311-hppa-linux-gnu.so',
+ 'EXT_SUFFIX': '.cpython-312-hppa-linux-gnu.so',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 1,
  'FREEZE_MODULE': './_bootstrap_python ./Programs/_freeze_module.py',
@@ -141,7 +145,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
  'HAVE_BROKEN_MBSTOWCS': 0,
- 'HAVE_BROKEN_NICE': 0,
+ 'HAVE_BROKEN_NICE': 1,
  'HAVE_BROKEN_PIPE_BUF': 0,
  'HAVE_BROKEN_POLL': 0,
  'HAVE_BROKEN_POSIX_SEMAPHORES': 0,
@@ -205,6 +209,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_DUP3': 1,
  'HAVE_DYLD_SHARED_CACHE_CONTAINS_PATH': 0,
  'HAVE_DYNAMIC_LOADING': 1,
+ 'HAVE_EDITLINE_READLINE_H': 0,
  'HAVE_ENDIAN_H': 1,
  'HAVE_EPOLL': 1,
  'HAVE_EPOLL_CREATE1': 1,
@@ -227,6 +232,9 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_FDOPENDIR': 1,
  'HAVE_FDWALK': 0,
  'HAVE_FEXECVE': 1,
+ 'HAVE_FFI_CLOSURE_ALLOC': 1,
+ 'HAVE_FFI_PREP_CIF_VAR': 1,
+ 'HAVE_FFI_PREP_CLOSURE_LOC': 1,
  'HAVE_FLOCK': 1,
  'HAVE_FORK': 1,
  'HAVE_FORK1': 0,
@@ -324,11 +332,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBDB': 0,
  'HAVE_LIBDL': 1,
  'HAVE_LIBDLD': 0,
- 'HAVE_LIBGDBM_COMPAT': 1,
  'HAVE_LIBIEEE': 0,
  'HAVE_LIBINTL_H': 1,
- 'HAVE_LIBNDBM': 0,
- 'HAVE_LIBREADLINE': 1,
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBSENDFILE': 0,
  'HAVE_LIBSQLITE3': 1,
@@ -342,6 +347,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 1,
  'HAVE_LINUX_CAN_RAW_H': 1,
  'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 1,
+ 'HAVE_LINUX_FS_H': 1,
  'HAVE_LINUX_LIMITS_H': 1,
  'HAVE_LINUX_MEMFD_H': 1,
  'HAVE_LINUX_NETLINK_H': 1,
@@ -375,6 +381,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MMAP': 1,
  'HAVE_MREMAP': 1,
  'HAVE_NANOSLEEP': 1,
+ 'HAVE_NCURSESW': 1,
  'HAVE_NCURSES_H': 1,
  'HAVE_NDBM_H': 0,
  'HAVE_NDIR_H': 0,
@@ -382,12 +389,14 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_NETDB_H': 1,
  'HAVE_NETINET_IN_H': 1,
  'HAVE_NETPACKET_PACKET_H': 1,
+ 'HAVE_NET_ETHERNET_H': 1,
  'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
  'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
  'HAVE_OPENAT': 1,
  'HAVE_OPENDIR': 1,
  'HAVE_OPENPTY': 1,
+ 'HAVE_PANEL_H': 1,
  'HAVE_PATHCONF': 1,
  'HAVE_PAUSE': 1,
  'HAVE_PIPE': 1,
@@ -417,6 +426,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
  'HAVE_PWRITEV2': 1,
+ 'HAVE_READLINE_READLINE_H': 0,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
@@ -455,6 +465,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SETITIMER': 1,
  'HAVE_SETJMP_H': 1,
  'HAVE_SETLOCALE': 1,
+ 'HAVE_SETNS': 1,
  'HAVE_SETPGID': 1,
  'HAVE_SETPGRP': 1,
  'HAVE_SETPRIORITY': 1,
@@ -493,7 +504,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STATVFS': 1,
  'HAVE_STAT_TV_NSEC': 1,
  'HAVE_STAT_TV_NSEC2': 0,
- 'HAVE_STDARG_PROTOTYPES': 1,
  'HAVE_STDINT_H': 1,
  'HAVE_STDIO_H': 1,
  'HAVE_STDLIB_H': 1,
@@ -579,6 +589,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 1,
+ 'HAVE_UNSHARE': 1,
  'HAVE_USABLE_WCHAR_T': 0,
  'HAVE_UTIL_H': 0,
  'HAVE_UTIMENSAT': 1,
@@ -607,44 +618,54 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_H': 0,
  'HAVE__GETPTY': 0,
  'HOSTRUNNER': '',
- 'HOST_GNU_TYPE': 'hppa1.1-unknown-linux-gnu',
- 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.11 '
-                   '/usr/include/python3.11',
+ 'HOST_GNU_TYPE': 'hppa2.0-unknown-linux-gnu',
+ 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.12 '
+                   '/usr/include/python3.12',
  'INCLUDEDIR': '/usr/include',
- 'INCLUDEPY': '/usr/include/python3.11',
+ 'INCLUDEPY': '/usr/include/python3.12',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'libpython3.11.so.1.0',
+ 'INSTSONAME': 'libpython3.12.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 'hppa1.1-unknown-linux-gnu-g++ -shared',
+ 'LDCXXSHARED': 'hppa2.0-unknown-linux-gnu-g++ -shared',
  'LDFLAGS': '',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.11.so',
+ 'LDLIBRARY': 'libpython3.12.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'hppa1.1-unknown-linux-gnu-gcc -shared',
- 'LDVERSION': '3.11',
+ 'LDSHARED': 'hppa2.0-unknown-linux-gnu-gcc -shared',
+ 'LDVERSION': '3.12',
  'LIBC': '',
- 'LIBDEST': '/usr/lib/python3.11',
+ 'LIBDEST': '/usr/lib/python3.12',
  'LIBDIR': '/usr/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=1.1 -fwrapv '
-                    '-std=c11 -Wextra -Wno-unused-parameter '
+ 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
+                    '-march=2.0 -fwrapv -std=c11 -Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
- 'LIBFFI_INCLUDEDIR': '/usr/lib/libffi/include',
+ 'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
+                   '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
+                   '-march=2.0 -fwrapv -std=c11 -Wextra -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
+                   '-I./Include/internal -I. -I./Include '
+                   '-I/usr/include/ncursesw -fPIC -fPIC',
+ 'LIBHACL_HEADERS': '\\',
+ 'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
+ 'LIBHACL_SHA2_HEADERS': '\\',
+ 'LIBHACL_SHA2_OBJS': '\\',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1 '
-                    '-Wsign-compare -DNDEBUG -O2 -pipe -march=1.1 -fwrapv '
-                    '-std=c11 -Wextra -Wno-unused-parameter '
+                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
+                    '-march=2.0 -fwrapv -std=c11 -Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
@@ -654,18 +675,18 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/lib/pkgconfig',
- 'LIBPL': '/usr/lib/python3.11/config-3.11-hppa-linux-gnu',
+ 'LIBPL': '/usr/lib/python3.12/config-3.12-hppa-linux-gnu',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.11.a',
- 'LIBRARY_DEPS': 'libpython3.11.so libpython3.so',
+ 'LIBRARY': 'libpython3.12.a',
+ 'LIBRARY_DEPS': 'libpython3.12.so libpython3.so',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-ldl',
  'LIBSUBDIRS': 'asyncio \\',
- 'LINKCC': 'hppa1.1-unknown-linux-gnu-gcc',
+ 'LINKCC': 'hppa2.0-unknown-linux-gnu-gcc',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
- 'LINK_PYTHON_DEPS': 'libpython3.11.so libpython3.so',
- 'LINK_PYTHON_OBJS': '-L. -lpython3.11',
+ 'LINK_PYTHON_DEPS': 'libpython3.12.so libpython3.so',
+ 'LINK_PYTHON_OBJS': '-L. -lpython3.12',
  'LIPO_32BIT_FLAGS': '',
  'LIPO_INTEL64_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
@@ -675,19 +696,33 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/lib/python3.11',
+ 'MACHDESTLIB': '/usr/lib/python3.12',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'hppa1.1-unknown-linux-gnu-gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/share/man',
- 'MKDIR_P': '/usr/bin/mkdir -p',
- 'MODBUILT_NAMES': 'atexit  faulthandler  posix  _signal  _tracemalloc  '
+ 'MKDIR_P': '/bin/mkdir -p',
+ 'MODBUILT_NAMES': 'array  _asyncio  _bisect  _contextvars  _csv  _heapq  '
+                   '_json  _lsprof  _opcode  _pickle  _queue  _random  '
+                   '_struct  _xxsubinterpreters  _xxinterpchannels  _zoneinfo  '
+                   'audioop  math  cmath  _statistics  _datetime  _decimal  '
+                   'binascii  _bz2  _lzma  zlib  _dbm  _gdbm  readline  _md5  '
+                   '_sha1  _sha2  _sha3  _blake2  pyexpat  _elementtree  '
+                   '_codecs_cn  _codecs_hk  _codecs_iso2022  _codecs_jp  '
+                   '_codecs_kr  _codecs_tw  _multibytecodec  unicodedata  '
+                   '_crypt  fcntl  grp  mmap  ossaudiodev  _posixsubprocess  '
+                   'resource  select  _socket  spwd  syslog  termios  '
+                   '_posixshmem  _multiprocessing  _ctypes  _curses  '
+                   '_curses_panel  _sqlite3  _ssl  _hashlib  _uuid  xxsubtype  '
+                   '_xxtestfuzz  _testbuffer  _testinternalcapi  _testcapi  '
+                   '_testclinic  _testimportmultiple  _testmultiphase  '
+                   '_testsinglephase  _ctypes_test  xxlimited  xxlimited_35  '
+                   'atexit  faulthandler  posix  _signal  _tracemalloc  '
                    '_codecs  _collections  errno  _io  itertools  _sre  '
-                   '_thread  time  _weakref  _abc  _functools  _locale  '
-                   '_operator  _stat  _symtable  pwd  xxsubtype',
- 'MODDISABLED_NAMES': '',
+                   '_thread  time  _typing  _weakref  _abc  _functools  '
+                   '_locale  _operator  _stat  _symtable  pwd',
+ 'MODDISABLED_NAMES': 'nis  _tkinter',
  'MODLIBS': '',
  'MODOBJS': 'Modules/atexitmodule.o  Modules/faulthandler.o  '
             'Modules/posixmodule.o  Modules/signalmodule.o  '
@@ -698,11 +733,24 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_io/textio.o Modules/_io/stringio.o  '
             'Modules/itertoolsmodule.o  Modules/_sre/sre.o  '
             'Modules/_threadmodule.o  Modules/timemodule.o  '
-            'Modules/_weakref.o  Modules/_abc.o  Modules/_functoolsmodule.o  '
-            'Modules/_localemodule.o  Modules/_operator.o  Modules/_stat.o  '
-            'Modules/symtablemodule.o  Modules/pwdmodule.o  '
-            'Modules/xxsubtype.o',
- 'MODSHARED_NAMES': '',
+            'Modules/_typingmodule.o  Modules/_weakref.o  Modules/_abc.o  '
+            'Modules/_functoolsmodule.o  Modules/_localemodule.o  '
+            'Modules/_operator.o  Modules/_stat.o  Modules/symtablemodule.o  '
+            'Modules/pwdmodule.o',
+ 'MODSHARED_NAMES': 'array _asyncio _bisect _contextvars _csv _heapq _json '
+                    '_lsprof _opcode _pickle _queue _random _struct '
+                    '_xxsubinterpreters _xxinterpchannels _zoneinfo audioop '
+                    'math cmath _statistics _datetime _decimal binascii _bz2 '
+                    '_lzma zlib _dbm _gdbm readline _md5 _sha1 _sha2 _sha3 '
+                    '_blake2 pyexpat _elementtree _codecs_cn _codecs_hk '
+                    '_codecs_iso2022 _codecs_jp _codecs_kr _codecs_tw '
+                    '_multibytecodec unicodedata _crypt fcntl grp mmap '
+                    'ossaudiodev _posixsubprocess resource select _socket spwd '
+                    'syslog termios _posixshmem _multiprocessing _ctypes '
+                    '_curses _curses_panel _sqlite3 _ssl _hashlib _uuid '
+                    'xxsubtype _xxtestfuzz _testbuffer _testinternalcapi '
+                    '_testcapi _testclinic _testimportmultiple _testmultiphase '
+                    '_testsinglephase _ctypes_test xxlimited xxlimited_35',
  'MODULE_ARRAY_STATE': 'yes',
  'MODULE_ATEXIT_LDFLAGS': '',
  'MODULE_AUDIOOP_LDFLAGS': '-lm',
@@ -713,6 +761,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_CMATH_DEPS': './Modules/_math.h',
  'MODULE_CMATH_LDFLAGS': '-lm',
  'MODULE_CMATH_STATE': 'yes',
+ 'MODULE_DEPS_SHARED': 'Modules/config.c',
+ 'MODULE_DEPS_STATIC': 'Modules/config.c',
  'MODULE_ERRNO_LDFLAGS': '',
  'MODULE_FAULTHANDLER_LDFLAGS': '',
  'MODULE_FCNTL_LDFLAGS': '',
@@ -725,7 +775,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_MMAP_STATE': 'yes',
  'MODULE_NIS_CFLAGS': '-I/usr/include/tirpc',
  'MODULE_NIS_LDFLAGS': '-lnsl -ltirpc',
- 'MODULE_NIS_STATE': 'disabled',
+ 'MODULE_NIS_STATE': 'yes',
  'MODULE_OBJS': '\\',
  'MODULE_OSSAUDIODEV_LDFLAGS': '',
  'MODULE_OSSAUDIODEV_STATE': 'yes',
@@ -736,6 +786,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_PYEXPAT_DEPS': '',
  'MODULE_PYEXPAT_LDFLAGS': '-lexpat',
  'MODULE_PYEXPAT_STATE': 'yes',
+ 'MODULE_READLINE_CFLAGS': '-D_DEFAULT_SOURCE',
+ 'MODULE_READLINE_LDFLAGS': '-lreadline',
  'MODULE_READLINE_STATE': 'yes',
  'MODULE_RESOURCE_STATE': 'yes',
  'MODULE_SELECT_STATE': 'yes',
@@ -749,7 +801,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_UNICODEDATA_STATE': 'yes',
  'MODULE_XXLIMITED_35_STATE': 'yes',
  'MODULE_XXLIMITED_STATE': 'yes',
- 'MODULE_XXSUBTYPE_LDFLAGS': '',
+ 'MODULE_XXSUBTYPE_STATE': 'yes',
  'MODULE_ZLIB_CFLAGS': '',
  'MODULE_ZLIB_LDFLAGS': '-lz',
  'MODULE_ZLIB_STATE': 'yes',
@@ -777,12 +829,35 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__BZ2_CFLAGS': '',
  'MODULE__BZ2_LDFLAGS': '-lbz2',
  'MODULE__BZ2_STATE': 'yes',
+ 'MODULE__CODECS_CN_DEPS': './Modules/cjkcodecs/mappings_cn.h '
+                           './Modules/cjkcodecs/multibytecodec.h '
+                           './Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_CN_STATE': 'yes',
+ 'MODULE__CODECS_HK_DEPS': './Modules/cjkcodecs/mappings_hk.h  '
+                           './Modules/cjkcodecs/multibytecodec.h '
+                           './Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_HK_STATE': 'yes',
+ 'MODULE__CODECS_ISO2022_DEPS': './Modules/cjkcodecs/mappings_jisx0213_pair.h '
+                                './Modules/cjkcodecs/alg_jisx0201.h '
+                                './Modules/cjkcodecs/emu_jisx0213_2000.h '
+                                './Modules/cjkcodecs/multibytecodec.h '
+                                './Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_ISO2022_STATE': 'yes',
+ 'MODULE__CODECS_JP_DEPS': './Modules/cjkcodecs/mappings_jisx0213_pair.h '
+                           './Modules/cjkcodecs/alg_jisx0201.h '
+                           './Modules/cjkcodecs/emu_jisx0213_2000.h '
+                           './Modules/cjkcodecs/mappings_jp.h '
+                           './Modules/cjkcodecs/multibytecodec.h '
+                           './Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_JP_STATE': 'yes',
+ 'MODULE__CODECS_KR_DEPS': './Modules/cjkcodecs/mappings_kr.h '
+                           './Modules/cjkcodecs/multibytecodec.h '
+                           './Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_KR_STATE': 'yes',
  'MODULE__CODECS_LDFLAGS': '',
+ 'MODULE__CODECS_TW_DEPS': './Modules/cjkcodecs/mappings_tw.h '
+                           './Modules/cjkcodecs/multibytecodec.h '
+                           './Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_TW_STATE': 'yes',
  'MODULE__COLLECTIONS_LDFLAGS': '',
  'MODULE__CONTEXTVARS_STATE': 'yes',
@@ -790,13 +865,24 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__CRYPT_LDFLAGS': '-lcrypt',
  'MODULE__CRYPT_STATE': 'yes',
  'MODULE__CSV_STATE': 'yes',
+ 'MODULE__CTYPES_CFLAGS': '-fno-strict-overflow -I/usr/lib/libffi/include',
  'MODULE__CTYPES_DEPS': './Modules/_ctypes/ctypes.h',
+ 'MODULE__CTYPES_LDFLAGS': '-lffi -ldl',
+ 'MODULE__CTYPES_MALLOC_CLOSURE': '',
+ 'MODULE__CTYPES_STATE': 'yes',
  'MODULE__CTYPES_TEST_LDFLAGS': '-lm',
  'MODULE__CTYPES_TEST_STATE': 'yes',
+ 'MODULE__CURSES_CFLAGS': '-D_DEFAULT_SOURCE  -I/usr/include/ncursesw',
+ 'MODULE__CURSES_LDFLAGS': '-lncursesw -ltinfow',
+ 'MODULE__CURSES_PANEL_CFLAGS': '-I/usr/include/ncursesw -D_DEFAULT_SOURCE  '
+                                '-D_DEFAULT_SOURCE  -I/usr/include/ncursesw',
+ 'MODULE__CURSES_PANEL_LDFLAGS': '-lpanelw -lncursesw -ltinfow',
  'MODULE__CURSES_PANEL_STATE': 'yes',
  'MODULE__CURSES_STATE': 'yes',
  'MODULE__DATETIME_LDFLAGS': '-lm',
  'MODULE__DATETIME_STATE': 'yes',
+ 'MODULE__DBM_CFLAGS': '-DUSE_GDBM_COMPAT',
+ 'MODULE__DBM_LDFLAGS': '-lgdbm_compat',
  'MODULE__DBM_STATE': 'yes',
  'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 '
                            '-DANSI=1',
@@ -826,8 +912,12 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__LZMA_CFLAGS': '',
  'MODULE__LZMA_LDFLAGS': '-llzma',
  'MODULE__LZMA_STATE': 'yes',
- 'MODULE__MD5_DEPS': './Modules/hashlib.h',
+ 'MODULE__MD5_CFLAGS': '-I./Modules/_hacl/include -I./Modules/_hacl/internal '
+                       '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
+ 'MODULE__MD5_DEPS': './Modules/hashlib.h \\ Modules/_hacl/Hacl_Hash_MD5.h '
+                     'Modules/_hacl/Hacl_Hash_MD5.c',
  'MODULE__MD5_STATE': 'yes',
+ 'MODULE__MULTIBYTECODEC_DEPS': './Modules/cjkcodecs/multibytecodec.h',
  'MODULE__MULTIBYTECODEC_STATE': 'yes',
  'MODULE__MULTIPROCESSING_CFLAGS': '-I./Modules/_multiprocessing',
  'MODULE__MULTIPROCESSING_STATE': 'yes',
@@ -841,15 +931,19 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__QUEUE_STATE': 'yes',
  'MODULE__RANDOM_STATE': 'yes',
  'MODULE__SCPROXY_STATE': 'n/a',
- 'MODULE__SHA1_DEPS': './Modules/hashlib.h',
+ 'MODULE__SHA1_CFLAGS': '-I./Modules/_hacl/include -I./Modules/_hacl/internal '
+                        '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
+ 'MODULE__SHA1_DEPS': './Modules/hashlib.h \\ Modules/_hacl/Hacl_Hash_SHA1.h '
+                      'Modules/_hacl/Hacl_Hash_SHA1.c',
  'MODULE__SHA1_STATE': 'yes',
- 'MODULE__SHA256_DEPS': './Modules/hashlib.h',
- 'MODULE__SHA256_STATE': 'yes',
- 'MODULE__SHA3_DEPS': './Modules/_sha3/sha3.c ./Modules/_sha3/sha3.h '
-                      './Modules/hashlib.h',
+ 'MODULE__SHA2_CFLAGS': '-I./Modules/_hacl/include -I./Modules/_hacl/internal '
+                        '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
+ 'MODULE__SHA2_DEPS': './Modules/hashlib.h \\ '
+                      'Modules/_hacl/libHacl_Hash_SHA2.a',
+ 'MODULE__SHA2_STATE': 'yes',
+ 'MODULE__SHA3_DEPS': './Modules/hashlib.h \\ Modules/_hacl/Hacl_Hash_SHA3.h '
+                      'Modules/_hacl/Hacl_Hash_SHA3.c',
  'MODULE__SHA3_STATE': 'yes',
- 'MODULE__SHA512_DEPS': './Modules/hashlib.h',
- 'MODULE__SHA512_STATE': 'yes',
  'MODULE__SIGNAL_LDFLAGS': '',
  'MODULE__SOCKET_DEPS': './Modules/socketmodule.h ./Modules/addrinfo.h '
                         './Modules/getaddrinfo.c ./Modules/getnameinfo.c',
@@ -877,20 +971,24 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__STRUCT_STATE': 'yes',
  'MODULE__SYMTABLE_LDFLAGS': '',
  'MODULE__TESTBUFFER_STATE': 'yes',
- 'MODULE__TESTCAPI_DEPS': './Modules/testcapi_long.h',
+ 'MODULE__TESTCAPI_DEPS': './Modules/_testcapi/testcapi_long.h '
+                          './Modules/_testcapi/parts.h '
+                          './Modules/_testcapi/util.h',
  'MODULE__TESTCAPI_STATE': 'yes',
  'MODULE__TESTCLINIC_STATE': 'yes',
  'MODULE__TESTIMPORTMULTIPLE_STATE': 'yes',
  'MODULE__TESTINTERNALCAPI_STATE': 'yes',
  'MODULE__TESTMULTIPHASE_STATE': 'yes',
  'MODULE__THREAD_LDFLAGS': '',
- 'MODULE__TKINTER_STATE': 'disabled',
+ 'MODULE__TKINTER_STATE': 'missing',
  'MODULE__TRACEMALLOC_LDFLAGS': '',
+ 'MODULE__TYPING_LDFLAGS': '',
  'MODULE__TYPING_STATE': 'yes',
  'MODULE__UUID_CFLAGS': '-I/usr/include/uuid',
  'MODULE__UUID_LDFLAGS': '-luuid',
  'MODULE__UUID_STATE': 'yes',
  'MODULE__WEAKREF_LDFLAGS': '',
+ 'MODULE__XXINTERPCHANNELS_STATE': 'yes',
  'MODULE__XXSUBINTERPRETERS_STATE': 'yes',
  'MODULE__XXTESTFUZZ_STATE': 'yes',
  'MODULE__ZONEINFO_STATE': 'yes',
@@ -899,12 +997,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPENSSL_INCLUDES': '',
- 'OPENSSL_LDFLAGS': '',
- 'OPENSSL_LIBS': '-lssl -lcrypto',
- 'OPENSSL_RPATH': '',
  'OPT': '-DNDEBUG',
- 'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -938,24 +1031,25 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_FOR_REGEN': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=1.1 '
-                             '-fwrapv -std=c11 -Wextra -Wno-unused-parameter '
+ 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
+ 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
+                             '-pipe -march=2.0 -fwrapv -std=c11 -Wextra '
+                             '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wsign-compare -DNDEBUG',
- 'PY_CFLAGS_NODIST': '-O2 -pipe -march=1.1 -fwrapv -std=c11 -Wextra '
+ 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG',
+ 'PY_CFLAGS_NODIST': '-O2 -pipe -march=2.0 -fwrapv -std=c11 -Wextra '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=1.1 -fwrapv '
-                   '-std=c11 -Wextra -Wno-unused-parameter '
+ 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
+                   '-march=2.0 -fwrapv -std=c11 -Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include '
@@ -963,7 +1057,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
  'PY_ENABLE_SHARED': 1,
- 'PY_FORMAT_SIZE_T': '"z"',
+ 'PY_HAVE_PERF_TRAMPOLINE': 0,
  'PY_LDFLAGS': '',
  'PY_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed',
  'PY_LDFLAGS_NOLTO': '',
@@ -971,9 +1065,10 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=1.1 -fwrapv '
-                        '-std=c11 -Wextra -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers -Wstrict-prototypes '
+ 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
+                        '-pipe -march=2.0 -fwrapv -std=c11 -Wextra '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -I/usr/include/ncursesw -fPIC',
@@ -985,13 +1080,93 @@ build_time_vars = {'ABIFLAGS': '',
  'Py_SUNOS_VERSION': 0,
  'Py_TRACE_REFS': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
- 'READELF': 'hppa1.1-unknown-linux-gnu-readelf',
+ 'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.9/work/Python-3.11.9',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.1_p1/work/Python-3.12.1',
  'SCRIPTDIR': '/usr/lib',
+ 'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
+ 'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
+ 'SCRIPT_PYDOC': 'build/scripts-3.12/pydoc3.12',
  'SETPGRP_HAVE_ARG': 0,
- 'SHELL': '/bin/sh',
+ 'SHAREDMODS': 'Modules/array.cpython-312-hppa-linux-gnu.so '
+               'Modules/_asyncio.cpython-312-hppa-linux-gnu.so '
+               'Modules/_bisect.cpython-312-hppa-linux-gnu.so '
+               'Modules/_contextvars.cpython-312-hppa-linux-gnu.so '
+               'Modules/_csv.cpython-312-hppa-linux-gnu.so '
+               'Modules/_heapq.cpython-312-hppa-linux-gnu.so '
+               'Modules/_json.cpython-312-hppa-linux-gnu.so '
+               'Modules/_lsprof.cpython-312-hppa-linux-gnu.so '
+               'Modules/_opcode.cpython-312-hppa-linux-gnu.so '
+               'Modules/_pickle.cpython-312-hppa-linux-gnu.so '
+               'Modules/_queue.cpython-312-hppa-linux-gnu.so '
+               'Modules/_random.cpython-312-hppa-linux-gnu.so '
+               'Modules/_struct.cpython-312-hppa-linux-gnu.so '
+               'Modules/_xxsubinterpreters.cpython-312-hppa-linux-gnu.so '
+               'Modules/_xxinterpchannels.cpython-312-hppa-linux-gnu.so '
+               'Modules/_zoneinfo.cpython-312-hppa-linux-gnu.so '
+               'Modules/audioop.cpython-312-hppa-linux-gnu.so '
+               'Modules/math.cpython-312-hppa-linux-gnu.so '
+               'Modules/cmath.cpython-312-hppa-linux-gnu.so '
+               'Modules/_statistics.cpython-312-hppa-linux-gnu.so '
+               'Modules/_datetime.cpython-312-hppa-linux-gnu.so '
+               'Modules/_decimal.cpython-312-hppa-linux-gnu.so '
+               'Modules/binascii.cpython-312-hppa-linux-gnu.so '
+               'Modules/_bz2.cpython-312-hppa-linux-gnu.so '
+               'Modules/_lzma.cpython-312-hppa-linux-gnu.so '
+               'Modules/zlib.cpython-312-hppa-linux-gnu.so '
+               'Modules/_dbm.cpython-312-hppa-linux-gnu.so '
+               'Modules/_gdbm.cpython-312-hppa-linux-gnu.so '
+               'Modules/readline.cpython-312-hppa-linux-gnu.so '
+               'Modules/_md5.cpython-312-hppa-linux-gnu.so '
+               'Modules/_sha1.cpython-312-hppa-linux-gnu.so '
+               'Modules/_sha2.cpython-312-hppa-linux-gnu.so '
+               'Modules/_sha3.cpython-312-hppa-linux-gnu.so '
+               'Modules/_blake2.cpython-312-hppa-linux-gnu.so '
+               'Modules/pyexpat.cpython-312-hppa-linux-gnu.so '
+               'Modules/_elementtree.cpython-312-hppa-linux-gnu.so '
+               'Modules/_codecs_cn.cpython-312-hppa-linux-gnu.so '
+               'Modules/_codecs_hk.cpython-312-hppa-linux-gnu.so '
+               'Modules/_codecs_iso2022.cpython-312-hppa-linux-gnu.so '
+               'Modules/_codecs_jp.cpython-312-hppa-linux-gnu.so '
+               'Modules/_codecs_kr.cpython-312-hppa-linux-gnu.so '
+               'Modules/_codecs_tw.cpython-312-hppa-linux-gnu.so '
+               'Modules/_multibytecodec.cpython-312-hppa-linux-gnu.so '
+               'Modules/unicodedata.cpython-312-hppa-linux-gnu.so '
+               'Modules/_crypt.cpython-312-hppa-linux-gnu.so '
+               'Modules/fcntl.cpython-312-hppa-linux-gnu.so '
+               'Modules/grp.cpython-312-hppa-linux-gnu.so '
+               'Modules/mmap.cpython-312-hppa-linux-gnu.so '
+               'Modules/ossaudiodev.cpython-312-hppa-linux-gnu.so '
+               'Modules/_posixsubprocess.cpython-312-hppa-linux-gnu.so '
+               'Modules/resource.cpython-312-hppa-linux-gnu.so '
+               'Modules/select.cpython-312-hppa-linux-gnu.so '
+               'Modules/_socket.cpython-312-hppa-linux-gnu.so '
+               'Modules/spwd.cpython-312-hppa-linux-gnu.so '
+               'Modules/syslog.cpython-312-hppa-linux-gnu.so '
+               'Modules/termios.cpython-312-hppa-linux-gnu.so '
+               'Modules/_posixshmem.cpython-312-hppa-linux-gnu.so '
+               'Modules/_multiprocessing.cpython-312-hppa-linux-gnu.so '
+               'Modules/_ctypes.cpython-312-hppa-linux-gnu.so '
+               'Modules/_curses.cpython-312-hppa-linux-gnu.so '
+               'Modules/_curses_panel.cpython-312-hppa-linux-gnu.so '
+               'Modules/_sqlite3.cpython-312-hppa-linux-gnu.so '
+               'Modules/_ssl.cpython-312-hppa-linux-gnu.so '
+               'Modules/_hashlib.cpython-312-hppa-linux-gnu.so '
+               'Modules/_uuid.cpython-312-hppa-linux-gnu.so '
+               'Modules/xxsubtype.cpython-312-hppa-linux-gnu.so '
+               'Modules/_xxtestfuzz.cpython-312-hppa-linux-gnu.so '
+               'Modules/_testbuffer.cpython-312-hppa-linux-gnu.so '
+               'Modules/_testinternalcapi.cpython-312-hppa-linux-gnu.so '
+               'Modules/_testcapi.cpython-312-hppa-linux-gnu.so '
+               'Modules/_testclinic.cpython-312-hppa-linux-gnu.so '
+               'Modules/_testimportmultiple.cpython-312-hppa-linux-gnu.so '
+               'Modules/_testmultiphase.cpython-312-hppa-linux-gnu.so '
+               'Modules/_testsinglephase.cpython-312-hppa-linux-gnu.so '
+               'Modules/_ctypes_test.cpython-312-hppa-linux-gnu.so '
+               'Modules/xxlimited.cpython-312-hppa-linux-gnu.so '
+               'Modules/xxlimited_35.cpython-312-hppa-linux-gnu.so',
+ 'SHELL': '/bin/sh -e',
  'SHLIBS': '-ldl',
  'SHLIB_SUFFIX': '.so',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
@@ -1014,11 +1189,11 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-311-hppa-linux-gnu',
+ 'SOABI': 'cpython-312-hppa-linux-gnu',
  'SRCDIRS': 'Modules   Modules/_blake2   Modules/_ctypes   Modules/_decimal   '
-            'Modules/_decimal/libmpdec   Modules/_io   '
-            'Modules/_multiprocessing   Modules/_sha3   Modules/_sqlite   '
-            'Modules/_sre   Modules/_xxtestfuzz   Modules/cjkcodecs   '
+            'Modules/_decimal/libmpdec   Modules/_hacl   Modules/_io   '
+            'Modules/_multiprocessing   Modules/_sqlite   Modules/_sre   '
+            'Modules/_testcapi   Modules/_xxtestfuzz   Modules/cjkcodecs   '
             'Modules/expat   Objects   Parser   Programs   Python   '
             'Python/frozen_modules   Python/deepfreeze',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
@@ -1032,26 +1207,25 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.9/work/Python-3.11.9 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.1_p1/work/Python-3.12.1 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.9/work/Python-3.11.9 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.1_p1/work/Python-3.12.1 '
                './python -E ./Tools/scripts/run_tests.py',
- 'TESTSUBDIRS': 'ctypes/test \\',
+ 'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
  'TEST_MODULES': 'yes',
  'THREAD_STACK_SIZE': 0,
  'TIMEMODULE_LIB': 0,
- 'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
  'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': './Tools/scripts/update_file.py',
+ 'UPDATE_FILE': './Tools/build/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
- 'VERSION': '3.11',
+ 'VERSION': '3.12',
  'WASM_ASSETS_DIR': './usr',
- 'WASM_STDLIB': './usr/lib/python3.11/os.py',
+ 'WASM_STDLIB': './usr/lib/python3.12/os.py',
  'WHEEL_PKG_DIR': '/usr/lib/python/ensurepip',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
@@ -1066,8 +1240,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.11.9/work/Python-3.11.9',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.11.9/work/Python-3.11.9',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.12.1_p1/work/Python-3.12.1',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.12.1_p1/work/Python-3.12.1',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
