@@ -9,6 +9,7 @@ import sys
 import threading
 import unittest
 from unittest import mock
+import warnings
 from test.support import socket_helper
 try:
     import ssl
@@ -790,11 +791,14 @@ os.close(fd)
         protocol = asyncio.StreamReaderProtocol(reader, loop=self.loop)
         transport, _ = self.loop.run_until_complete(
             self.loop.connect_read_pipe(lambda: protocol, pipe))
-
-        watcher = asyncio.SafeChildWatcher()
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore', DeprecationWarning)
+            watcher = asyncio.SafeChildWatcher()
         watcher.attach_loop(self.loop)
         try:
-            asyncio.set_child_watcher(watcher)
+            with warnings.catch_warnings():
+                warnings.simplefilter('ignore', DeprecationWarning)
+                asyncio.set_child_watcher(watcher)
             create = asyncio.create_subprocess_exec(
                 *args,
                 pass_fds={wfd},
@@ -802,7 +806,9 @@ os.close(fd)
             proc = self.loop.run_until_complete(create)
             self.loop.run_until_complete(proc.wait())
         finally:
-            asyncio.set_child_watcher(None)
+            with warnings.catch_warnings():
+                warnings.simplefilter('ignore', DeprecationWarning)
+                asyncio.set_child_watcher(None)
 
         os.close(wfd)
         data = self.loop.run_until_complete(reader.read(-1))
@@ -824,7 +830,7 @@ os.close(fd)
     def test_streamreader_constructor_use_global_loop(self):
         # asyncio issue #184: Ensure that StreamReaderProtocol constructor
         # retrieves the current loop if the loop parameter is not set
-        # Deprecated in 3.10, undeprecated in 3.11.1
+        # Deprecated in 3.10, undeprecated in 3.12
         self.addCleanup(asyncio.set_event_loop, None)
         asyncio.set_event_loop(self.loop)
         reader = asyncio.StreamReader()
@@ -848,7 +854,7 @@ os.close(fd)
     def test_streamreaderprotocol_constructor_use_global_loop(self):
         # asyncio issue #184: Ensure that StreamReaderProtocol constructor
         # retrieves the current loop if the loop parameter is not set
-        # Deprecated in 3.10, undeprecated in 3.11.1
+        # Deprecated in 3.10, undeprecated in 3.12
         self.addCleanup(asyncio.set_event_loop, None)
         asyncio.set_event_loop(self.loop)
         reader = mock.Mock()
@@ -1123,7 +1129,7 @@ os.close(fd)
 
         self.assertEqual(messages, [])
 
-    def _basetest_unhandled_exceptions(self, handle_echo):
+    def test_unhandled_exceptions(self) -> None:
         port = socket_helper.find_unused_port()
 
         messages = []
@@ -1137,6 +1143,9 @@ os.close(fd)
             await wr.wait_closed()
 
         async def main():
+            async def handle_echo(reader, writer):
+                raise Exception('test')
+
             server = await asyncio.start_server(
                 handle_echo, 'localhost', port)
             await server.start_serving()
@@ -1145,20 +1154,11 @@ os.close(fd)
             await server.wait_closed()
 
         self.loop.run_until_complete(main())
-        return messages
 
-    def test_unhandled_exception(self):
-        async def handle_echo(reader, writer):
-            raise Exception('test')
-        messages = self._basetest_unhandled_exceptions(handle_echo)
         self.assertEqual(messages[0]['message'],
-                    'Unhandled exception in client_connected_cb')
-
-    def test_unhandled_cancel(self):
-        async def handle_echo(reader, writer):
-            asyncio.current_task().cancel()
-        messages = self._basetest_unhandled_exceptions(handle_echo)
-        self.assertEqual(messages, [])
+                         'Unhandled exception in client_connected_cb')
+        # Break explicitly reference cycle
+        messages = None
 
 
 if __name__ == '__main__':
